@@ -8,16 +8,23 @@ This module provides a webservice API with several endpoints:
 The endpoints use Pydantic models for request and response validation.
 """
 
+import os
 from collections.abc import Generator
-from enum import StrEnum
 from typing import Annotated
 
 from fastapi import Depends, FastAPI, Response, status
 from pydantic import BaseModel, Field
 
-from oe_python_template import Service
+from . import Echo, Health, HealthStatus, Service, Utterance
 
+TITLE = "OE Python Template"
 HELLO_WORLD_EXAMPLE = "Hello, world!"
+UVICORN_HOST = os.environ.get("UVICORN_HOST", "127.0.0.1")
+UVICORN_PORT = os.environ.get("UVICORN_PORT", "8000")
+CONTACT_NAME = "Helmut Hoffer von Ankershoffen"
+CONTACT_EMAIL = "helmuthva@gmail.com"
+CONTACT_URL = "https://github.com/helmut-hoffer-von-ankershoffen"
+TERMS_OF_SERVICE_URL = "https://oe-python-template.readthedocs.io/en/latest/"
 
 
 def get_service() -> Generator[Service, None, None]:
@@ -36,82 +43,56 @@ def get_service() -> Generator[Service, None, None]:
 
 api = FastAPI(
     root_path="/api",
-    title="OE Python Template",
+    title=TITLE,
     contact={
-        "name": "Helmut Hoffer von Ankershoffen",
-        "email": "helmuthva@gmail.com",
-        "url": "https://github.com/helmut-hoffer-von-ankershoffen",
+        "name": CONTACT_NAME,
+        "email": CONTACT_EMAIL,
+        "url": CONTACT_URL,
     },
-    terms_of_service="https://oe-python-template.readthedocs.io/en/latest/",
+    terms_of_service=TERMS_OF_SERVICE_URL,
     openapi_tags=[
         {
             "name": "v1",
             "description": "API version 1, check link on the right",
-            "externalDocs": {"description": "sub-docs", "url": "/api/v1/docs"},
+            "externalDocs": {
+                "description": "sub-docs",
+                "url": f"http://{UVICORN_HOST}:{UVICORN_PORT}/api/v1/docs",
+            },
         },
         {
             "name": "v2",
             "description": "API version 2, check link on the right",
-            "externalDocs": {"description": "sub-docs", "url": "/api/v2/docs"},
+            "externalDocs": {
+                "description": "sub-docs",
+                "url": f"http://{UVICORN_HOST}:{UVICORN_PORT}/api/v2/docs",
+            },
         },
     ],
 )
 
 api_v1 = FastAPI(
     version="1.0.0",
-    title="OE Python Template",
+    title=TITLE,
     contact={
-        "name": "Helmut Hoffer von Ankershoffen",
-        "email": "helmuthva@gmail.com",
-        "url": "https://github.com/helmut-hoffer-von-ankershoffen",
+        "name": CONTACT_NAME,
+        "email": CONTACT_EMAIL,
+        "url": CONTACT_URL,
     },
-    terms_of_service="https://oe-python-template.readthedocs.io/en/latest/",
+    terms_of_service=TERMS_OF_SERVICE_URL,
 )
 
 api_v2 = FastAPI(
     version="2.0.0",
-    title="OE Python Template",
+    title=TITLE,
     contact={
-        "name": "Helmut Hoffer von Ankershoffen",
-        "email": "helmuthva@gmail.com",
-        "url": "https://github.com/helmut-hoffer-von-ankershoffen",
+        "name": CONTACT_NAME,
+        "email": CONTACT_EMAIL,
+        "url": CONTACT_URL,
     },
-    terms_of_service="https://oe-python-template.readthedocs.io/en/latest/",
+    terms_of_service=TERMS_OF_SERVICE_URL,
 )
 
 
-class _HealthStatus(StrEnum):
-    """Health status enumeration.
-
-    Args:
-        StrEnum (_type_): _description_
-    """
-
-    UP = "UP"
-    DOWN = "DOWN"
-
-
-class Health(BaseModel):
-    """Health status model.
-
-    Args:
-        BaseModel (_type_): _description_
-    """
-
-    status: _HealthStatus
-    reason: str | None = None
-
-
-class HealthResponse(BaseModel):
-    """Response model for health endpoint."""
-
-    health: str = Field(
-        ...,
-        description="The hello world message",
-        examples=[HELLO_WORLD_EXAMPLE],
-    )
-
-
 @api_v1.get("/healthz", tags=["Observability"])
 @api_v1.get("/health", tags=["Observability"])
 @api_v2.get("/healthz", tags=["Observability"])
@@ -126,25 +107,21 @@ async def health(service: Annotated[Service, Depends(get_service)], response: Re
     The response will have a 200 OK status code if the service is healthy,
     and a 500 Internal Server Error status code if the service is unhealthy.
 
-    Args:
-        service (Annotated[Service, Depends): _description_
-        response (Response): _description_
-
     Returns:
         Health: The health status of the service.
     """
     if service.healthy():
-        health_result = Health(status=_HealthStatus.UP)
+        health_result = Health(status=HealthStatus.UP)
     else:
-        health_result = Health(status=_HealthStatus.DOWN, reason="Service is unhealthy")
+        health_result = Health(status=HealthStatus.DOWN, reason="Service is unhealthy")
 
-    if health_result.status == _HealthStatus.DOWN:
+    if health_result.status == HealthStatus.DOWN:
         response.status_code = status.HTTP_500_INTERNAL_SERVER_ERROR
 
     return health_result
 
 
-class HelloWorldResponse(BaseModel):
+class _HelloWorldResponse(BaseModel):
     """Response model for hello-world endpoint."""
 
     message: str = Field(
@@ -156,81 +133,48 @@ class HelloWorldResponse(BaseModel):
 
 @api_v1.get("/hello-world", tags=["Basics"])
 @api_v2.get("/hello-world", tags=["Basics"])
-async def hello_world() -> HelloWorldResponse:
+async def hello_world(service: Annotated[Service, Depends(get_service)]) -> _HelloWorldResponse:
     """
     Return a hello world message.
 
     Returns:
-        HelloWorldResponse: A response containing the hello world message.
+        _HelloWorldResponse: A response containing the hello world message.
     """
-    return HelloWorldResponse(message=Service.get_hello_world())
+    return _HelloWorldResponse(message=service.get_hello_world())
 
 
-class EchoResponse(BaseModel):
-    """Response model for echo endpoint."""
-
-    message: str = Field(
-        ...,
-        min_length=1,
-        description="The message content",
-        examples=[HELLO_WORLD_EXAMPLE],
-    )
-
-
-class EchoRequest(BaseModel):
-    """Request model for echo endpoint."""
-
-    text: str = Field(
-        ...,
-        min_length=1,
-        description="The text to echo back",
-        examples=[HELLO_WORLD_EXAMPLE],
-    )
-
-
-@api_v1.post("/echo", tags=["Basics"])
-async def echo(request: EchoRequest) -> EchoResponse:
+@api_v1.get("/echo/{text}", tags=["Basics"])
+async def echo(text: str) -> Echo:
     """
     Echo back the provided text.
 
     Args:
-        request (EchoRequest): The request containing the text to echo back.
+        text (str): The text to echo.
 
     Returns:
-        EchoResponse: A response containing the echoed text.
+        Echo: The echo.
 
     Raises:
         422 Unprocessable Entity: If text is not provided or empty.
     """
-    return EchoResponse(message=request.text)
-
-
-class Utterance(BaseModel):
-    """Request model for echo endpoint."""
-
-    utterance: str = Field(
-        ...,
-        min_length=1,
-        description="The utterance to echo back",
-        examples=[HELLO_WORLD_EXAMPLE],
-    )
+    return Service.echo(Utterance(text=text))
 
 
 @api_v2.post("/echo", tags=["Basics"])
-async def echo_v2(request: Utterance) -> EchoResponse:
+async def echo_v2(request: Utterance) -> Echo:
     """
     Echo back the provided utterance.
 
     Args:
-        request (EchoRequestV2): The request containing the utterance to echo back.
+        request (Utterance): The utterance to echo back.
 
     Returns:
-        EchoResponse: A response containing the echoed utterance.
+        Echo: The echo.
 
     Raises:
         422 Unprocessable Entity: If utterance is not provided or empty.
     """
-    return EchoResponse(message=request.utterance)
+    return Service.echo(request)
 
 
 api.mount("/v1", api_v1)
